@@ -6,7 +6,7 @@ import subprocess
 import requests
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
-from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
+from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileAppendTransaction, FileInfoQuery
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -44,18 +44,15 @@ class Network3Medusa():
                 else:
                     self.append_file_to_hedera(chunk)           
             if WEBEX_ROOM:
-                self.send_webex_notification()
-            query = FileInfoQuery().setFileId(self.fileId)
-            info = query.execute(self.client)
-            print("File size according to `FileInfoQuery`: ", info.size)            
+                self.send_webex_notification()          
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
-    def add_file_to_hedera(self, raw_json):
+    def add_file_to_hedera(self, chunk):
         self.client = Client.forTestnet()
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        fileContents = raw_json
+        fileContents = chunk
         print(fileContents)
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
@@ -66,6 +63,7 @@ class Network3Medusa():
         info = query.execute(self.client)
         print("file: ",  self.fileId.toString())
         print("File size according to `FileInfoQuery`: ", info.size)
+
     def append_file_to_hedera(self, interface):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
